Waldur MasterMind
=================

Waldur MasterMind is part of the Waldur suite - https://waldur.com - for managing of hybrid cloud resources.
It is used for building marketplaces, self-service portals and for managing in-house IT resources.

License
-------
Waldur MasterMind is released under MIT license.

Documentation
-------------

Please use `all-in-one bootstrap script <https://github.com/opennode/waldur-mastermind/blob/develop/docs/guide/bootstrap.sh>`_
to install Waldur core and all plugins in development mode or update them to the latest versions.
Also it is assumed that you've already activated virtual Python environment before running this script.

Administration and usage guides can be found at http://docs.waldur.com .

Support
-------

For professional support and integration services please contact info@opennodecloud.com.
